@@ -1,18 +1,17 @@
 /*
-@ @licstart  The following is the entire license notice for the
+@licstart  The following is the entire license notice for the
 JavaScript code in this file.
 
-Copyright (C) 1997-2017 by Dimitri van Heesch
+Copyright (C) 1997-2019 by Dimitri van Heesch
 
 This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.
+it under the terms of version 2 of the GNU General Public License as published by
+the Free Software Foundation
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License along
 with this program; if not, write to the Free Software Foundation, Inc.,
@@ -57,11 +56,11 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "a00551.html",
-"a00789.html#a1c85ed58e2e3362dd22fbdb815f2c5a3",
-"a00865.html#a9afad522b48b3d7a0fe296ec26e1484b",
-"a00961.html",
-"a01057.html#a9cf40ecf1b9b5c29507fe92a03f37a3c",
-"a01133.html#abede89f527e6fcfb1af012878a9978cc",
+"a00789.html#a14bf987459715b918b370247bb24a61c",
+"a00865.html#aa71d36872f416feaa853788a7a7a7ef8",
+"a00961.html#a154f068140b02b8324cfa70cdbe1191c",
+"a01057.html#a9d8ecd607dbb0749a55113224fbd39c4",
+"a01133.html#ad46ad6c30664729d163c5fcc20cdf917",
 "a01185.html#a6e1a910b772d22272d7876c4c29648e6a09ea5a566322e694b61b81303eeb369f",
 "a01205.html#aee0ff6081195e50afec79b3698c83748"
 ];
